<?php namespace EscapeWork\Manager\Calendars\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Calendars\Repositories\CalendarRepository;
use EscapeWork\Manager\Calendars\Repositories\CalendarDayRepository;
use View, Input, Redirect, Config;

class CalendarsController extends ManagerController
{

    public function __construct(CalendarRepository $calendar, CalendarDayRepository $calendarDay)
    {
        parent::__construct();

        $this->calendar    = $calendar;
        $this->calendarDay = $calendarDay;

        $this->validatePermissions('calendars');
    }

    public function index()
    {
        return View::make(Config::get('manager-calendars::views.calendars.index'), [
            'calendars' => $this->calendar->filterAndPaginate(Input::all()),
        ]);
    }

    public function create()
    {
        $this->calendar->fill(Input::old());

        return View::make(Config::get('manager-calendars::views.calendars.form'), [
            'calendar'    => $this->calendar,
            'calendarDay' => $this->calendarDay,
            'edit'        => false,
        ]);
    }

    public function store()
    {
        $this->calendar->fill(Input::except('date'));

        if (! $this->calendar->validate()) {
            return Redirect::route('manager.calendarios.create')
                        ->withInput()
                        ->withErrors($this->calendar->messages());
        }

        $this->calendar->save();
        $this->calendarDay->calendar_id = $this->calendar->id;
        $this->calendarDay->insertFromArray(Input::get('date'));

        return Redirect::route('manager.calendarios.index')
                       ->with('message', 'O evento <strong>' . $this->calendar->title . '</strong> foi inserido com sucesso!');
    }

    public function edit($id)
    {
        $this->calendar->findOrFail($id);

        return View::make(Config::get('manager-calendars::views.calendars.form'), [
            'calendar'    => $this->calendar,
            'calendarDay' => $this->calendarDay,
            'edit'        => true,
        ]);
    }

    public function update($id)
    {
        $this->calendar->findOrFail($id);
        $this->calendar->fill(Input::all());

        if ( $this->calendar->validate() === false) {
            return Redirect::route('manager.calendarios.edit', array($this->calendar->id))
                    ->withInput()
                    ->withErrors($this->calendar->messages());
        }

        $this->calendar->save();

        # salvando as datas
        $this->calendarDay->calendar_id = $this->calendar->id;
        $this->calendarDay->deleteAllFromEdition();
        $this->calendarDay->insertFromArray(Input::get('date'));

        return Redirect::route('manager.calendarios.index')
                ->with('message', 'A edição <strong>'.$this->calendar->title.'</strong> foi editada com sucesso!');
    }

    public function destroy($id)
    {
        $this->calendar->findOrFail($id);
        $this->calendar->delete();

        return Redirect::route('manager.calendarios.index')
                ->with('message', 'O evento <strong>'.$this->calendar->title.'</strong> foi excluído com sucesso!');
    }
}
