<?php namespace EscapeWork\Manager\Calendars\Models;

use EscapeWork\LaravelHelpers\BaseModel;
use EscapeWork\LaravelHelpers\SluggableTrait;
use InvalidArgumentException;

class Calendar extends BaseModel
{

    /**
     * Table
     */
    protected $table = 'calendars';

    /**
     * Sluggable
     */
    use SluggableTrait;

    /**
     * Fillable fields
     */
    protected $fillable = array(
        'title',
        'place',
        'description',
        'featured',
        'active',
    );

    /**
    * Regras de validação
    */
    public $validationRules = array(
        'title' => array('required'),
        'place' => array('required'),
    );

    /**
    * Mensagens de validação
    */
    public $validationMessages = array(
        'title.required' => 'O titulo do evento é obrigatório',
        'place.required' => 'O local do evento é obrigatório',
    );

    /**
     * Escopo para noticias ativas
     */
    public function scopeActive($query)
    {
        return $query->where('active', '=', 1);
    }

    /**
     * Escopo para noticias ativas
     */
    public function scopeFeatured($query)
    {
        return $query->where('featured', '=', 1);
    }

    /**
     * Join com a tabela de dias
     */
    public function scopeJoinDays($query)
    {
        return $query->join('calendar_days', 'calendars.id', '=', 'calendar_days.calendar_id');
    }

    /**
     * Escopo para apenas eventos que não passaram
     */
    public function scopeFutureEvents($query)
    {
        return $query->where('calendar_days.day', '>=', date('Y-m-d'));
    }

    /**
     * Um evento possue muitas datas
     */
    public function days()
    {
        return $this->hasMany('EscapeWork\Manager\Calendars\Models\CalendarDay', 'calendar_id')
                    ->orderBy('day');
    }
}
