@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a></li>
        <li><a href="{{ route('manager.calendarios.index') }}">Calendário</a></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Calendário</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.calendarios.index') }}" class="btn">Voltar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

   @include('manager::inc.messages')

    <form action="{{ ! $edit ? route('manager.calendarios.store') : route('manager.calendarios.update', $calendar->id) }}" method="post" id="form-calendar" class="form-horizontal">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            @section('fields')
                <div class="form-group">
                    <label for="title" class="col-sm-2 control-label">Título</label>

                    <div class="col-sm-8">
                        <input type="text" name="title" id="title" class="form-control" value="{{ $calendar->title }}" required autofocus />
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="form-group">
                    <label for="place" class="col-sm-2 control-label">Local</label>

                    <div class="col-sm-8">
                        <input type="text" name="place" id="place" class="form-control" value="{{ $calendar->place }}" required />
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="form-group">
                    <label for="description" class="col-sm-2 control-label">Descrição</label>

                    <div class="col-sm-8">
                        <textarea  name="description" id="description" data-editor>{{ $calendar->description }}</textarea>
                    </div><!-- .controls -->
                </div><!-- .control-group -->

                <div class="form-group">
                    <label for="date" class="col-sm-2 control-label">Data</label>

                    <div class="col-sm-3 js-date-group">
                        @if ((!$edit) || (count($calendar->days) == 0))
                            <div>
                                <div class="input-group">
                                    <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                                    <input type="text" name="date[]" class="form-control" placeholder="dd/mm/aaaa" data-date data-calendar maxlength="10" required />

                                    <span class="input-group-btn">
                                        <button type="button" class="btn btn-primary js-add-date" title="Adicionar data" data-name="date[]">
                                            <span class="input-addon">
                                                <span class="glyphicon glyphicon-plus glyphicon-white"></span>
                                            </span>
                                        </button>
                                    </span>
                                </div><!-- .input-append -->
                            </div>

                        @else
                            @foreach ($calendar->days as $calendarDay)
                                <div>
                                    <div class="input-group">
                                        <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                                        <input type="text" name="date[]" value="{{ date('d/m/Y', strtotime($calendarDay->day)) }}" class="form-control" placeholder="dd/mm/aaaa" data-date data-calendar maxlength="10" required />


                                        <a href="#" class="input-group-addon btn btn-default js-delete-date" title="Excluir data">
                                            <span class="input-addon"><span class="glyphicon glyphicon-trash"></span></span>
                                        </a>

                                        <span class="input-group-btn">
                                            <button type="button" class="btn btn-primary js-add-date" title="Adicionar data" data-name="date[]">
                                                <span class="input-addon">
                                                    <span class="glyphicon glyphicon-plus glyphicon-white"></span>
                                                </span>
                                            </button>
                                        </span>
                                    </div><!-- .input-group -->

                                </div>
                            @endforeach
                        @endif
                    </div><!-- .col-sm-10 -->
                </div><!-- .form-group -->
            @show
        </fieldset>

        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <input type="submit" class="btn btn-primary" value="Salvar">
                <a href="{{ route('manager.calendarios.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-group -->
    </form>
@stop

@section('scripts')
    @parent

    <script type="text/template" id="template-date">
        <div>
            <div class="input-group">
                <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                <input type="text" name="##name##" class="form-control" placeholder="dd/mm/aaaa" data-date data-calendar maxlength="10" />


                <a href="#" class="input-group-addon btn btn-default js-delete-date" title="Excluir data">
                    <span class="input-addon"><span class="glyphicon glyphicon-trash"></span></span>
                </a>
            </div><!-- .input-group -->

        </div>
    </script>

    <script type="text/javascript">
        (function() {
            window.App = window.App || {};

            App.Manager = App.Manager || {};

            App.Manager.ProductEditions = {
                templates: {
                    date: $('#template-date')
                },

                wrapper: {
                    datepicker: '[data-calendar]'
                },

                init: function() {
                    this.fetchElements();
                    this.setMasks();
                    this.listenEvents();
                },

                fetchElements: function() {
                    this.$dateGroup = $('.js-date-group');
                    this.$btnAddDate = $('.js-add-date');
                    this.$btnDeleteDate = $('.js-delete-date');
                },

                setMasks: function() {
                    $('[data-date]').mask('99/99/9999');

                    this.initDatepicker();
                },

                initDatepicker: function(config) {
                    var _this;

                    _this = this;
                    $(this.wrapper.datepicker).datepicker({

                        onSelect: function(date) {
                            _this.defaultDate = date;
                            return $(_this.wrapper.datepicker).datepicker('option', 'defaultDate', date);
                        },

                        defaultDate: _this.defaultDate
                    });
                },

                listenEvents: function() {
                    var _this;

                    _this = this;
                    this.$btnAddDate.on('click', function(e) {
                        e.preventDefault();
                        return _this.onAddDate($(this));
                    });

                    this.listenDeleteDateEvent();
                },

                listenDeleteDateEvent: function() {
                    var _this;

                    _this = this;

                    return this.$btnDeleteDate.on('click', function(e) {
                        e.preventDefault();
                        return _this.onDeleteDate($(this));
                    });
                },

                onAddDate: function($btn) {
                    var date, name;

                    name = $btn.data('name');
                    date = this.templates.date.html().replace(/##name##/ig, name);

                    this.$dateGroup.append(date);

                    this.fetchElements();
                    this.listenDeleteDateEvent();
                    this.setMasks();
                },

                onDeleteDate: function($btn) {
                    return $btn.parent().remove();
                }
            };

            App.Manager.ProductEditions.init();
        }).call(this);
    </script>
@stop
